#ifndef ENTRY_H
#define ENTRY_H

#include <qwidget.h>
#include <qstringlist.h>
#include <qlist.h>

class QLineEdit;
class QVBoxLayout;
class QGridLayout;

class Entry : public QWidget
{
	Q_OBJECT
	public:
		Entry(QWidget *parent = NULL, const char *name = NULL);
		~Entry();
		void init(int type);
		void init2(QString type);
		void fill(QStringList list);

	public slots:
		void slotAccept();

	signals:
		void signalNewTrack(QStringList list);

	private:
		QVBoxLayout *vbox;
		QGridLayout *grid;
		QList<QLineEdit> editlist;
};

#endif

